# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v2/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/accesslog/v2/als.proto',
  package='envoy.config.accesslog.v2',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.accesslog.v2B\010AlsProtoP\001\362\230\376\217\005)\022\'envoy.extensions.access_loggers.grpc.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/config/accesslog/v2/als.proto\x12\x19\x65nvoy.config.accesslog.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf4\x01\n\x17HttpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12)\n!additional_request_headers_to_log\x18\x02 \x03(\t\x12*\n\"additional_response_headers_to_log\x18\x03 \x03(\t\x12+\n#additional_response_trailers_to_log\x18\x04 \x03(\t\"o\n\x16TcpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x98\x02\n\x19\x43ommonGrpcAccessLogConfig\x12\x19\n\x08log_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12>\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x42\n\x15\x62uffer_flush_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x37\n\x11\x62uffer_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x1b\x66ilter_state_objects_to_log\x18\x05 \x03(\tBl\n\'io.envoyproxy.envoy.config.accesslog.v2B\x08\x41lsProtoP\x01\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.access_loggers.grpc.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HTTPGRPCACCESSLOGCONFIG = _descriptor.Descriptor(
  name='HttpGrpcAccessLogConfig',
  full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_request_headers_to_log', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.additional_request_headers_to_log', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_response_headers_to_log', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.additional_response_headers_to_log', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_response_trailers_to_log', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.additional_response_trailers_to_log', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=501,
)


_TCPGRPCACCESSLOGCONFIG = _descriptor.Descriptor(
  name='TcpGrpcAccessLogConfig',
  full_name='envoy.config.accesslog.v2.TcpGrpcAccessLogConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.config.accesslog.v2.TcpGrpcAccessLogConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=614,
)


_COMMONGRPCACCESSLOGCONFIG = _descriptor.Descriptor(
  name='CommonGrpcAccessLogConfig',
  full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_name', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.log_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.grpc_service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_flush_interval', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.buffer_flush_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_size_bytes', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.buffer_size_bytes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state_objects_to_log', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.filter_state_objects_to_log', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=897,
)

_HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config'].message_type = _COMMONGRPCACCESSLOGCONFIG
_TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config'].message_type = _COMMONGRPCACCESSLOGCONFIG
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_size_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['HttpGrpcAccessLogConfig'] = _HTTPGRPCACCESSLOGCONFIG
DESCRIPTOR.message_types_by_name['TcpGrpcAccessLogConfig'] = _TCPGRPCACCESSLOGCONFIG
DESCRIPTOR.message_types_by_name['CommonGrpcAccessLogConfig'] = _COMMONGRPCACCESSLOGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpGrpcAccessLogConfig = _reflection.GeneratedProtocolMessageType('HttpGrpcAccessLogConfig', (_message.Message,), {
  'DESCRIPTOR' : _HTTPGRPCACCESSLOGCONFIG,
  '__module__' : 'envoy.config.accesslog.v2.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v2.HttpGrpcAccessLogConfig)
  })
_sym_db.RegisterMessage(HttpGrpcAccessLogConfig)

TcpGrpcAccessLogConfig = _reflection.GeneratedProtocolMessageType('TcpGrpcAccessLogConfig', (_message.Message,), {
  'DESCRIPTOR' : _TCPGRPCACCESSLOGCONFIG,
  '__module__' : 'envoy.config.accesslog.v2.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v2.TcpGrpcAccessLogConfig)
  })
_sym_db.RegisterMessage(TcpGrpcAccessLogConfig)

CommonGrpcAccessLogConfig = _reflection.GeneratedProtocolMessageType('CommonGrpcAccessLogConfig', (_message.Message,), {
  'DESCRIPTOR' : _COMMONGRPCACCESSLOGCONFIG,
  '__module__' : 'envoy.config.accesslog.v2.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v2.CommonGrpcAccessLogConfig)
  })
_sym_db.RegisterMessage(CommonGrpcAccessLogConfig)


DESCRIPTOR._options = None
_HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
_TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._options = None
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._options = None
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/ratelimit/v2/rls.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.ratelimit import ratelimit_pb2 as envoy_dot_api_dot_v2_dot_ratelimit_dot_ratelimit__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/ratelimit/v2/rls.proto',
  package='envoy.service.ratelimit.v2',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.ratelimit.v2B\010RlsProtoP\001\210\001\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/ratelimit/v2/rls.proto\x12\x1a\x65nvoy.service.ratelimit.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a&envoy/api/v2/ratelimit/ratelimit.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"y\n\x10RateLimitRequest\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12@\n\x0b\x64\x65scriptors\x18\x02 \x03(\x0b\x32+.envoy.api.v2.ratelimit.RateLimitDescriptor\x12\x13\n\x0bhits_addend\x18\x03 \x01(\r\"\xf1\x05\n\x11RateLimitResponse\x12H\n\x0coverall_code\x18\x01 \x01(\x0e\x32\x32.envoy.service.ratelimit.v2.RateLimitResponse.Code\x12P\n\x08statuses\x18\x02 \x03(\x0b\x32>.envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus\x12P\n\x07headers\x18\x03 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValueB\x1f\xf2\x98\xfe\x8f\x05\x19\n\x17response_headers_to_add\x12>\n\x16request_headers_to_add\x18\x04 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x1a\xc0\x01\n\tRateLimit\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11requests_per_unit\x18\x01 \x01(\r\x12J\n\x04unit\x18\x02 \x01(\x0e\x32<.envoy.service.ratelimit.v2.RateLimitResponse.RateLimit.Unit\">\n\x04Unit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06SECOND\x10\x01\x12\n\n\x06MINUTE\x10\x02\x12\x08\n\x04HOUR\x10\x03\x12\x07\n\x03\x44\x41Y\x10\x04\x1a\xbd\x01\n\x10\x44\x65scriptorStatus\x12@\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x32.envoy.service.ratelimit.v2.RateLimitResponse.Code\x12N\n\rcurrent_limit\x18\x02 \x01(\x0b\x32\x37.envoy.service.ratelimit.v2.RateLimitResponse.RateLimit\x12\x17\n\x0flimit_remaining\x18\x03 \x01(\r\"+\n\x04\x43ode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0e\n\nOVER_LIMIT\x10\x02\x32\x84\x01\n\x10RateLimitService\x12p\n\x0fShouldRateLimit\x12,.envoy.service.ratelimit.v2.RateLimitRequest\x1a-.envoy.service.ratelimit.v2.RateLimitResponse\"\x00\x42\x41\n(io.envoyproxy.envoy.service.ratelimit.v2B\x08RlsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_ratelimit_dot_ratelimit__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])



_RATELIMITRESPONSE_RATELIMIT_UNIT = _descriptor.EnumDescriptor(
  name='Unit',
  full_name='envoy.service.ratelimit.v2.RateLimitResponse.RateLimit.Unit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECOND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=779,
  serialized_end=841,
)
_sym_db.RegisterEnumDescriptor(_RATELIMITRESPONSE_RATELIMIT_UNIT)

_RATELIMITRESPONSE_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='envoy.service.ratelimit.v2.RateLimitResponse.Code',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVER_LIMIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1035,
  serialized_end=1078,
)
_sym_db.RegisterEnumDescriptor(_RATELIMITRESPONSE_CODE)


_RATELIMITREQUEST = _descriptor.Descriptor(
  name='RateLimitRequest',
  full_name='envoy.service.ratelimit.v2.RateLimitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain', full_name='envoy.service.ratelimit.v2.RateLimitRequest.domain', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptors', full_name='envoy.service.ratelimit.v2.RateLimitRequest.descriptors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hits_addend', full_name='envoy.service.ratelimit.v2.RateLimitRequest.hits_addend', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=322,
)


_RATELIMITRESPONSE_RATELIMIT = _descriptor.Descriptor(
  name='RateLimit',
  full_name='envoy.service.ratelimit.v2.RateLimitResponse.RateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.service.ratelimit.v2.RateLimitResponse.RateLimit.name', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requests_per_unit', full_name='envoy.service.ratelimit.v2.RateLimitResponse.RateLimit.requests_per_unit', index=1,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='envoy.service.ratelimit.v2.RateLimitResponse.RateLimit.unit', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RATELIMITRESPONSE_RATELIMIT_UNIT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=841,
)

_RATELIMITRESPONSE_DESCRIPTORSTATUS = _descriptor.Descriptor(
  name='DescriptorStatus',
  full_name='envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_limit', full_name='envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus.current_limit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_remaining', full_name='envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus.limit_remaining', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=1033,
)

_RATELIMITRESPONSE = _descriptor.Descriptor(
  name='RateLimitResponse',
  full_name='envoy.service.ratelimit.v2.RateLimitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall_code', full_name='envoy.service.ratelimit.v2.RateLimitResponse.overall_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statuses', full_name='envoy.service.ratelimit.v2.RateLimitResponse.statuses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.ratelimit.v2.RateLimitResponse.headers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\230\376\217\005\031\n\027response_headers_to_add', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.service.ratelimit.v2.RateLimitResponse.request_headers_to_add', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMITRESPONSE_RATELIMIT, _RATELIMITRESPONSE_DESCRIPTORSTATUS, ],
  enum_types=[
    _RATELIMITRESPONSE_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=1078,
)

_RATELIMITREQUEST.fields_by_name['descriptors'].message_type = envoy_dot_api_dot_v2_dot_ratelimit_dot_ratelimit__pb2._RATELIMITDESCRIPTOR
_RATELIMITRESPONSE_RATELIMIT.fields_by_name['unit'].enum_type = _RATELIMITRESPONSE_RATELIMIT_UNIT
_RATELIMITRESPONSE_RATELIMIT.containing_type = _RATELIMITRESPONSE
_RATELIMITRESPONSE_RATELIMIT_UNIT.containing_type = _RATELIMITRESPONSE_RATELIMIT
_RATELIMITRESPONSE_DESCRIPTORSTATUS.fields_by_name['code'].enum_type = _RATELIMITRESPONSE_CODE
_RATELIMITRESPONSE_DESCRIPTORSTATUS.fields_by_name['current_limit'].message_type = _RATELIMITRESPONSE_RATELIMIT
_RATELIMITRESPONSE_DESCRIPTORSTATUS.containing_type = _RATELIMITRESPONSE
_RATELIMITRESPONSE.fields_by_name['overall_code'].enum_type = _RATELIMITRESPONSE_CODE
_RATELIMITRESPONSE.fields_by_name['statuses'].message_type = _RATELIMITRESPONSE_DESCRIPTORSTATUS
_RATELIMITRESPONSE.fields_by_name['headers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_RATELIMITRESPONSE.fields_by_name['request_headers_to_add'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_RATELIMITRESPONSE_CODE.containing_type = _RATELIMITRESPONSE
DESCRIPTOR.message_types_by_name['RateLimitRequest'] = _RATELIMITREQUEST
DESCRIPTOR.message_types_by_name['RateLimitResponse'] = _RATELIMITRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimitRequest = _reflection.GeneratedProtocolMessageType('RateLimitRequest', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITREQUEST,
  '__module__' : 'envoy.service.ratelimit.v2.rls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v2.RateLimitRequest)
  })
_sym_db.RegisterMessage(RateLimitRequest)

RateLimitResponse = _reflection.GeneratedProtocolMessageType('RateLimitResponse', (_message.Message,), {

  'RateLimit' : _reflection.GeneratedProtocolMessageType('RateLimit', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITRESPONSE_RATELIMIT,
    '__module__' : 'envoy.service.ratelimit.v2.rls_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v2.RateLimitResponse.RateLimit)
    })
  ,

  'DescriptorStatus' : _reflection.GeneratedProtocolMessageType('DescriptorStatus', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITRESPONSE_DESCRIPTORSTATUS,
    '__module__' : 'envoy.service.ratelimit.v2.rls_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus)
    })
  ,
  'DESCRIPTOR' : _RATELIMITRESPONSE,
  '__module__' : 'envoy.service.ratelimit.v2.rls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ratelimit.v2.RateLimitResponse)
  })
_sym_db.RegisterMessage(RateLimitResponse)
_sym_db.RegisterMessage(RateLimitResponse.RateLimit)
_sym_db.RegisterMessage(RateLimitResponse.DescriptorStatus)


DESCRIPTOR._options = None
_RATELIMITRESPONSE.fields_by_name['headers']._options = None

_RATELIMITSERVICE = _descriptor.ServiceDescriptor(
  name='RateLimitService',
  full_name='envoy.service.ratelimit.v2.RateLimitService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1081,
  serialized_end=1213,
  methods=[
  _descriptor.MethodDescriptor(
    name='ShouldRateLimit',
    full_name='envoy.service.ratelimit.v2.RateLimitService.ShouldRateLimit',
    index=0,
    containing_service=None,
    input_type=_RATELIMITREQUEST,
    output_type=_RATELIMITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RATELIMITSERVICE)

DESCRIPTOR.services_by_name['RateLimitService'] = _RATELIMITSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/admission_control/v3alpha/admission_control.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/admission_control/v3alpha/admission_control.proto',
  package='envoy.extensions.filters.http.admission_control.v3alpha',
  syntax='proto3',
  serialized_options=b'\nEio.envoyproxy.envoy.extensions.filters.http.admission_control.v3alphaB\025AdmissionControlProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nOenvoy/extensions/filters/http/admission_control/v3alpha/admission_control.proto\x12\x37\x65nvoy.extensions.filters.http.admission_control.v3alpha\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa4\x06\n\x10\x41\x64missionControl\x12\x39\n\x07\x65nabled\x18\x01 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12u\n\x10success_criteria\x18\x02 \x01(\x0b\x32Y.envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteriaH\x00\x12\x32\n\x0fsampling_window\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\naggression\x18\x04 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeDouble\x12:\n\x0csr_threshold\x18\x05 \x01(\x0b\x32$.envoy.config.core.v3.RuntimePercent\x1a\x98\x03\n\x0fSuccessCriteria\x12}\n\rhttp_criteria\x18\x01 \x01(\x0b\x32\x66.envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.HttpCriteria\x12}\n\rgrpc_criteria\x18\x02 \x01(\x0b\x32\x66.envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.GrpcCriteria\x1aP\n\x0cHttpCriteria\x12@\n\x13http_success_status\x18\x01 \x03(\x0b\x32\x19.envoy.type.v3.Int32RangeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x35\n\x0cGrpcCriteria\x12%\n\x13grpc_success_status\x18\x01 \x03(\rB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x1a\n\x13\x65valuation_criteria\x12\x03\xf8\x42\x01\x42p\nEio.envoyproxy.envoy.extensions.filters.http.admission_control.v3alphaB\x15\x41\x64missionControlProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_range__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA = _descriptor.Descriptor(
  name='HttpCriteria',
  full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.HttpCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_success_status', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.HttpCriteria.http_success_status', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=930,
  serialized_end=1010,
)

_ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA = _descriptor.Descriptor(
  name='GrpcCriteria',
  full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.GrpcCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_success_status', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.GrpcCriteria.grpc_success_status', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1065,
)

_ADMISSIONCONTROL_SUCCESSCRITERIA = _descriptor.Descriptor(
  name='SuccessCriteria',
  full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_criteria', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.http_criteria', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_criteria', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.grpc_criteria', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA, _ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=1065,
)

_ADMISSIONCONTROL = _descriptor.Descriptor(
  name='AdmissionControl',
  full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_criteria', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.success_criteria', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_window', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.sampling_window', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggression', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.aggression', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr_threshold', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.sr_threshold', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADMISSIONCONTROL_SUCCESSCRITERIA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='evaluation_criteria', full_name='envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.evaluation_criteria',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=289,
  serialized_end=1093,
)

_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA.fields_by_name['http_success_status'].message_type = envoy_dot_type_dot_v3_dot_range__pb2._INT32RANGE
_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA.containing_type = _ADMISSIONCONTROL_SUCCESSCRITERIA
_ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA.containing_type = _ADMISSIONCONTROL_SUCCESSCRITERIA
_ADMISSIONCONTROL_SUCCESSCRITERIA.fields_by_name['http_criteria'].message_type = _ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA
_ADMISSIONCONTROL_SUCCESSCRITERIA.fields_by_name['grpc_criteria'].message_type = _ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA
_ADMISSIONCONTROL_SUCCESSCRITERIA.containing_type = _ADMISSIONCONTROL
_ADMISSIONCONTROL.fields_by_name['enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFEATUREFLAG
_ADMISSIONCONTROL.fields_by_name['success_criteria'].message_type = _ADMISSIONCONTROL_SUCCESSCRITERIA
_ADMISSIONCONTROL.fields_by_name['sampling_window'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ADMISSIONCONTROL.fields_by_name['aggression'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEDOUBLE
_ADMISSIONCONTROL.fields_by_name['sr_threshold'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEPERCENT
_ADMISSIONCONTROL.oneofs_by_name['evaluation_criteria'].fields.append(
  _ADMISSIONCONTROL.fields_by_name['success_criteria'])
_ADMISSIONCONTROL.fields_by_name['success_criteria'].containing_oneof = _ADMISSIONCONTROL.oneofs_by_name['evaluation_criteria']
DESCRIPTOR.message_types_by_name['AdmissionControl'] = _ADMISSIONCONTROL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdmissionControl = _reflection.GeneratedProtocolMessageType('AdmissionControl', (_message.Message,), {

  'SuccessCriteria' : _reflection.GeneratedProtocolMessageType('SuccessCriteria', (_message.Message,), {

    'HttpCriteria' : _reflection.GeneratedProtocolMessageType('HttpCriteria', (_message.Message,), {
      'DESCRIPTOR' : _ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA,
      '__module__' : 'envoy.extensions.filters.http.admission_control.v3alpha.admission_control_pb2'
      # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.HttpCriteria)
      })
    ,

    'GrpcCriteria' : _reflection.GeneratedProtocolMessageType('GrpcCriteria', (_message.Message,), {
      'DESCRIPTOR' : _ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA,
      '__module__' : 'envoy.extensions.filters.http.admission_control.v3alpha.admission_control_pb2'
      # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria.GrpcCriteria)
      })
    ,
    'DESCRIPTOR' : _ADMISSIONCONTROL_SUCCESSCRITERIA,
    '__module__' : 'envoy.extensions.filters.http.admission_control.v3alpha.admission_control_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl.SuccessCriteria)
    })
  ,
  'DESCRIPTOR' : _ADMISSIONCONTROL,
  '__module__' : 'envoy.extensions.filters.http.admission_control.v3alpha.admission_control_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.admission_control.v3alpha.AdmissionControl)
  })
_sym_db.RegisterMessage(AdmissionControl)
_sym_db.RegisterMessage(AdmissionControl.SuccessCriteria)
_sym_db.RegisterMessage(AdmissionControl.SuccessCriteria.HttpCriteria)
_sym_db.RegisterMessage(AdmissionControl.SuccessCriteria.GrpcCriteria)


DESCRIPTOR._options = None
_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA.fields_by_name['http_success_status']._options = None
_ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA.fields_by_name['grpc_success_status']._options = None
_ADMISSIONCONTROL.oneofs_by_name['evaluation_criteria']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v4alpha/http_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/v4alpha/http_inputs.proto',
  package='envoy.type.matcher.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.type.matcher.v4alphaB\017HttpInputsProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,envoy/type/matcher/v4alpha/http_inputs.proto\x12\x1a\x65nvoy.type.matcher.v4alpha\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"l\n\x1bHttpRequestHeaderMatchInput\x12\x13\n\x0bheader_name\x18\x01 \x01(\t:8\x9a\xc5\x88\x1e\x33\n1envoy.type.matcher.v3.HttpRequestHeaderMatchInput\"n\n\x1cHttpResponseHeaderMatchInput\x12\x13\n\x0bheader_name\x18\x01 \x01(\t:9\x9a\xc5\x88\x1e\x34\n2envoy.type.matcher.v3.HttpResponseHeaderMatchInputBE\n(io.envoyproxy.envoy.type.matcher.v4alphaB\x0fHttpInputsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_HTTPREQUESTHEADERMATCHINPUT = _descriptor.Descriptor(
  name='HttpRequestHeaderMatchInput',
  full_name='envoy.type.matcher.v4alpha.HttpRequestHeaderMatchInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.type.matcher.v4alpha.HttpRequestHeaderMatchInput.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.type.matcher.v3.HttpRequestHeaderMatchInput',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=250,
)


_HTTPRESPONSEHEADERMATCHINPUT = _descriptor.Descriptor(
  name='HttpResponseHeaderMatchInput',
  full_name='envoy.type.matcher.v4alpha.HttpResponseHeaderMatchInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.type.matcher.v4alpha.HttpResponseHeaderMatchInput.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.type.matcher.v3.HttpResponseHeaderMatchInput',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=362,
)

DESCRIPTOR.message_types_by_name['HttpRequestHeaderMatchInput'] = _HTTPREQUESTHEADERMATCHINPUT
DESCRIPTOR.message_types_by_name['HttpResponseHeaderMatchInput'] = _HTTPRESPONSEHEADERMATCHINPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpRequestHeaderMatchInput = _reflection.GeneratedProtocolMessageType('HttpRequestHeaderMatchInput', (_message.Message,), {
  'DESCRIPTOR' : _HTTPREQUESTHEADERMATCHINPUT,
  '__module__' : 'envoy.type.matcher.v4alpha.http_inputs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v4alpha.HttpRequestHeaderMatchInput)
  })
_sym_db.RegisterMessage(HttpRequestHeaderMatchInput)

HttpResponseHeaderMatchInput = _reflection.GeneratedProtocolMessageType('HttpResponseHeaderMatchInput', (_message.Message,), {
  'DESCRIPTOR' : _HTTPRESPONSEHEADERMATCHINPUT,
  '__module__' : 'envoy.type.matcher.v4alpha.http_inputs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v4alpha.HttpResponseHeaderMatchInput)
  })
_sym_db.RegisterMessage(HttpResponseHeaderMatchInput)


DESCRIPTOR._options = None
_HTTPREQUESTHEADERMATCHINPUT._options = None
_HTTPRESPONSEHEADERMATCHINPUT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/annotations/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='udpa/annotations/status.proto',
  package='udpa.annotations',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dudpa/annotations/status.proto\x12\x10udpa.annotations\x1a google/protobuf/descriptor.proto\"t\n\x10StatusAnnotation\x12\x18\n\x10work_in_progress\x18\x01 \x01(\x08\x12\x46\n\x16package_version_status\x18\x02 \x01(\x0e\x32&.udpa.annotations.PackageVersionStatus*]\n\x14PackageVersionStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x46ROZEN\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12 \n\x1cNEXT_MAJOR_VERSION_CANDIDATE\x10\x03:X\n\x0b\x66ile_status\x12\x1c.google.protobuf.FileOptions\x18\x87\x80\x99j \x01(\x0b\x32\".udpa.annotations.StatusAnnotationb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_PACKAGEVERSIONSTATUS = _descriptor.EnumDescriptor(
  name='PackageVersionStatus',
  full_name='udpa.annotations.PackageVersionStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FROZEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEXT_MAJOR_VERSION_CANDIDATE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=203,
  serialized_end=296,
)
_sym_db.RegisterEnumDescriptor(_PACKAGEVERSIONSTATUS)

PackageVersionStatus = enum_type_wrapper.EnumTypeWrapper(_PACKAGEVERSIONSTATUS)
UNKNOWN = 0
FROZEN = 1
ACTIVE = 2
NEXT_MAJOR_VERSION_CANDIDATE = 3

FILE_STATUS_FIELD_NUMBER = 222707719
file_status = _descriptor.FieldDescriptor(
  name='file_status', full_name='udpa.annotations.file_status', index=0,
  number=222707719, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_STATUSANNOTATION = _descriptor.Descriptor(
  name='StatusAnnotation',
  full_name='udpa.annotations.StatusAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='work_in_progress', full_name='udpa.annotations.StatusAnnotation.work_in_progress', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package_version_status', full_name='udpa.annotations.StatusAnnotation.package_version_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=201,
)

_STATUSANNOTATION.fields_by_name['package_version_status'].enum_type = _PACKAGEVERSIONSTATUS
DESCRIPTOR.message_types_by_name['StatusAnnotation'] = _STATUSANNOTATION
DESCRIPTOR.enum_types_by_name['PackageVersionStatus'] = _PACKAGEVERSIONSTATUS
DESCRIPTOR.extensions_by_name['file_status'] = file_status
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusAnnotation = _reflection.GeneratedProtocolMessageType('StatusAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _STATUSANNOTATION,
  '__module__' : 'udpa.annotations.status_pb2'
  # @@protoc_insertion_point(class_scope:udpa.annotations.StatusAnnotation)
  })
_sym_db.RegisterMessage(StatusAnnotation)

file_status.message_type = _STATUSANNOTATION
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(file_status)

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/type/v1/typed_struct.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='udpa/type/v1/typed_struct.proto',
  package='udpa.type.v1',
  syntax='proto3',
  serialized_options=b'\n\034com.github.udpa.udpa.type.v1B\020TypedStructProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fudpa/type/v1/typed_struct.proto\x12\x0cudpa.type.v1\x1a\x17validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"G\n\x0bTypedStruct\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB2\n\x1c\x63om.github.udpa.udpa.type.v1B\x10TypedStructProtoP\x01\x62\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_TYPEDSTRUCT = _descriptor.Descriptor(
  name='TypedStruct',
  full_name='udpa.type.v1.TypedStruct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_url', full_name='udpa.type.v1.TypedStruct.type_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='udpa.type.v1.TypedStruct.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=175,
)

_TYPEDSTRUCT.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['TypedStruct'] = _TYPEDSTRUCT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TypedStruct = _reflection.GeneratedProtocolMessageType('TypedStruct', (_message.Message,), {
  'DESCRIPTOR' : _TYPEDSTRUCT,
  '__module__' : 'udpa.type.v1.typed_struct_pb2'
  # @@protoc_insertion_point(class_scope:udpa.type.v1.TypedStruct)
  })
_sym_db.RegisterMessage(TypedStruct)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v4alpha/event_service_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v4alpha/event_service_config.proto',
  package='envoy.config.core.v4alpha',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.core.v4alphaB\027EventServiceConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/config/core/v4alpha/event_service_config.proto\x12\x19\x65nvoy.config.core.v4alpha\x1a,envoy/config/core/v4alpha/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa4\x01\n\x12\x45ventServiceConfig\x12>\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32&.envoy.config.core.v4alpha.GrpcServiceH\x00:.\x9a\xc5\x88\x1e)\n\'envoy.config.core.v3.EventServiceConfigB\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01\x42L\n\'io.envoyproxy.envoy.config.core.v4alphaB\x17\x45ventServiceConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EVENTSERVICECONFIG = _descriptor.Descriptor(
  name='EventServiceConfig',
  full_name='envoy.config.core.v4alpha.EventServiceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.core.v4alpha.EventServiceConfig.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.config.core.v3.EventServiceConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_source_specifier', full_name='envoy.config.core.v4alpha.EventServiceConfig.config_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=221,
  serialized_end=385,
)

_EVENTSERVICECONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2._GRPCSERVICE
_EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier'].fields.append(
  _EVENTSERVICECONFIG.fields_by_name['grpc_service'])
_EVENTSERVICECONFIG.fields_by_name['grpc_service'].containing_oneof = _EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier']
DESCRIPTOR.message_types_by_name['EventServiceConfig'] = _EVENTSERVICECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventServiceConfig = _reflection.GeneratedProtocolMessageType('EventServiceConfig', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSERVICECONFIG,
  '__module__' : 'envoy.config.core.v4alpha.event_service_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v4alpha.EventServiceConfig)
  })
_sym_db.RegisterMessage(EventServiceConfig)


DESCRIPTOR._options = None
_EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier']._options = None
_EVENTSERVICECONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/transport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.data.tap.v3 import common_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v3/transport.proto',
  package='envoy.data.tap.v3',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.data.tap.v3B\016TransportProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/data/tap/v3/transport.proto\x12\x11\x65nvoy.data.tap.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1e\x65nvoy/data/tap/v3/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xa3\x01\n\nConnection\x12\x34\n\rlocal_address\x18\x02 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12\x35\n\x0eremote_address\x18\x03 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address:(\x9a\xc5\x88\x1e#\n!envoy.data.tap.v2alpha.Connection\"\xae\x04\n\x0bSocketEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04read\x18\x02 \x01(\x0b\x32#.envoy.data.tap.v3.SocketEvent.ReadH\x00\x12\x35\n\x05write\x18\x03 \x01(\x0b\x32$.envoy.data.tap.v3.SocketEvent.WriteH\x00\x12\x37\n\x06\x63losed\x18\x04 \x01(\x0b\x32%.envoy.data.tap.v3.SocketEvent.ClosedH\x00\x1a]\n\x04Read\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body:.\x9a\xc5\x88\x1e)\n\'envoy.data.tap.v2alpha.SocketEvent.Read\x1as\n\x05Write\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body\x12\x12\n\nend_stream\x18\x02 \x01(\x08:/\x9a\xc5\x88\x1e*\n(envoy.data.tap.v2alpha.SocketEvent.Write\x1a:\n\x06\x43losed:0\x9a\xc5\x88\x1e+\n)envoy.data.tap.v2alpha.SocketEvent.Closed:)\x9a\xc5\x88\x1e$\n\"envoy.data.tap.v2alpha.SocketEventB\x10\n\x0e\x65vent_selector\"\xee\x01\n\x13SocketBufferedTrace\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x31\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.Connection\x12.\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1e.envoy.data.tap.v3.SocketEvent\x12\x16\n\x0eread_truncated\x18\x04 \x01(\x08\x12\x17\n\x0fwrite_truncated\x18\x05 \x01(\x08:1\x9a\xc5\x88\x1e,\n*envoy.data.tap.v2alpha.SocketBufferedTrace\"\xdf\x01\n\x1aSocketStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x33\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.ConnectionH\x00\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1e.envoy.data.tap.v3.SocketEventH\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegmentB\x0f\n\rmessage_pieceB;\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0eTransportProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v3_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_CONNECTION = _descriptor.Descriptor(
  name='Connection',
  full_name='envoy.data.tap.v3.Connection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local_address', full_name='envoy.data.tap.v3.Connection.local_address', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_address', full_name='envoy.data.tap.v3.Connection.remote_address', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.data.tap.v2alpha.Connection',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=387,
)


_SOCKETEVENT_READ = _descriptor.Descriptor(
  name='Read',
  full_name='envoy.data.tap.v3.SocketEvent.Read',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='envoy.data.tap.v3.SocketEvent.Read.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.data.tap.v2alpha.SocketEvent.Read',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=710,
)

_SOCKETEVENT_WRITE = _descriptor.Descriptor(
  name='Write',
  full_name='envoy.data.tap.v3.SocketEvent.Write',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='envoy.data.tap.v3.SocketEvent.Write.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_stream', full_name='envoy.data.tap.v3.SocketEvent.Write.end_stream', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.data.tap.v2alpha.SocketEvent.Write',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=827,
)

_SOCKETEVENT_CLOSED = _descriptor.Descriptor(
  name='Closed',
  full_name='envoy.data.tap.v3.SocketEvent.Closed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.data.tap.v2alpha.SocketEvent.Closed',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=887,
)

_SOCKETEVENT = _descriptor.Descriptor(
  name='SocketEvent',
  full_name='envoy.data.tap.v3.SocketEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='envoy.data.tap.v3.SocketEvent.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read', full_name='envoy.data.tap.v3.SocketEvent.read', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write', full_name='envoy.data.tap.v3.SocketEvent.write', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closed', full_name='envoy.data.tap.v3.SocketEvent.closed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOCKETEVENT_READ, _SOCKETEVENT_WRITE, _SOCKETEVENT_CLOSED, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.data.tap.v2alpha.SocketEvent',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_selector', full_name='envoy.data.tap.v3.SocketEvent.event_selector',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=390,
  serialized_end=948,
)


_SOCKETBUFFEREDTRACE = _descriptor.Descriptor(
  name='SocketBufferedTrace',
  full_name='envoy.data.tap.v3.SocketBufferedTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.data.tap.v3.SocketBufferedTrace.trace_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='envoy.data.tap.v3.SocketBufferedTrace.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='envoy.data.tap.v3.SocketBufferedTrace.events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_truncated', full_name='envoy.data.tap.v3.SocketBufferedTrace.read_truncated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_truncated', full_name='envoy.data.tap.v3.SocketBufferedTrace.write_truncated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.data.tap.v2alpha.SocketBufferedTrace',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=1189,
)


_SOCKETSTREAMEDTRACESEGMENT = _descriptor.Descriptor(
  name='SocketStreamedTraceSegment',
  full_name='envoy.data.tap.v3.SocketStreamedTraceSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.trace_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegment',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message_piece', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.message_piece',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1192,
  serialized_end=1415,
)

_CONNECTION.fields_by_name['local_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_CONNECTION.fields_by_name['remote_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_SOCKETEVENT_READ.fields_by_name['data'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_common__pb2._BODY
_SOCKETEVENT_READ.containing_type = _SOCKETEVENT
_SOCKETEVENT_WRITE.fields_by_name['data'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_common__pb2._BODY
_SOCKETEVENT_WRITE.containing_type = _SOCKETEVENT
_SOCKETEVENT_CLOSED.containing_type = _SOCKETEVENT
_SOCKETEVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SOCKETEVENT.fields_by_name['read'].message_type = _SOCKETEVENT_READ
_SOCKETEVENT.fields_by_name['write'].message_type = _SOCKETEVENT_WRITE
_SOCKETEVENT.fields_by_name['closed'].message_type = _SOCKETEVENT_CLOSED
_SOCKETEVENT.oneofs_by_name['event_selector'].fields.append(
  _SOCKETEVENT.fields_by_name['read'])
_SOCKETEVENT.fields_by_name['read'].containing_oneof = _SOCKETEVENT.oneofs_by_name['event_selector']
_SOCKETEVENT.oneofs_by_name['event_selector'].fields.append(
  _SOCKETEVENT.fields_by_name['write'])
_SOCKETEVENT.fields_by_name['write'].containing_oneof = _SOCKETEVENT.oneofs_by_name['event_selector']
_SOCKETEVENT.oneofs_by_name['event_selector'].fields.append(
  _SOCKETEVENT.fields_by_name['closed'])
_SOCKETEVENT.fields_by_name['closed'].containing_oneof = _SOCKETEVENT.oneofs_by_name['event_selector']
_SOCKETBUFFEREDTRACE.fields_by_name['connection'].message_type = _CONNECTION
_SOCKETBUFFEREDTRACE.fields_by_name['events'].message_type = _SOCKETEVENT
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['connection'].message_type = _CONNECTION
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['event'].message_type = _SOCKETEVENT
_SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _SOCKETSTREAMEDTRACESEGMENT.fields_by_name['connection'])
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['connection'].containing_oneof = _SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _SOCKETSTREAMEDTRACESEGMENT.fields_by_name['event'])
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['event'].containing_oneof = _SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
DESCRIPTOR.message_types_by_name['Connection'] = _CONNECTION
DESCRIPTOR.message_types_by_name['SocketEvent'] = _SOCKETEVENT
DESCRIPTOR.message_types_by_name['SocketBufferedTrace'] = _SOCKETBUFFEREDTRACE
DESCRIPTOR.message_types_by_name['SocketStreamedTraceSegment'] = _SOCKETSTREAMEDTRACESEGMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.Connection)
  })
_sym_db.RegisterMessage(Connection)

SocketEvent = _reflection.GeneratedProtocolMessageType('SocketEvent', (_message.Message,), {

  'Read' : _reflection.GeneratedProtocolMessageType('Read', (_message.Message,), {
    'DESCRIPTOR' : _SOCKETEVENT_READ,
    '__module__' : 'envoy.data.tap.v3.transport_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent.Read)
    })
  ,

  'Write' : _reflection.GeneratedProtocolMessageType('Write', (_message.Message,), {
    'DESCRIPTOR' : _SOCKETEVENT_WRITE,
    '__module__' : 'envoy.data.tap.v3.transport_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent.Write)
    })
  ,

  'Closed' : _reflection.GeneratedProtocolMessageType('Closed', (_message.Message,), {
    'DESCRIPTOR' : _SOCKETEVENT_CLOSED,
    '__module__' : 'envoy.data.tap.v3.transport_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent.Closed)
    })
  ,
  'DESCRIPTOR' : _SOCKETEVENT,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent)
  })
_sym_db.RegisterMessage(SocketEvent)
_sym_db.RegisterMessage(SocketEvent.Read)
_sym_db.RegisterMessage(SocketEvent.Write)
_sym_db.RegisterMessage(SocketEvent.Closed)

SocketBufferedTrace = _reflection.GeneratedProtocolMessageType('SocketBufferedTrace', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETBUFFEREDTRACE,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketBufferedTrace)
  })
_sym_db.RegisterMessage(SocketBufferedTrace)

SocketStreamedTraceSegment = _reflection.GeneratedProtocolMessageType('SocketStreamedTraceSegment', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETSTREAMEDTRACESEGMENT,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketStreamedTraceSegment)
  })
_sym_db.RegisterMessage(SocketStreamedTraceSegment)


DESCRIPTOR._options = None
_CONNECTION._options = None
_SOCKETEVENT_READ._options = None
_SOCKETEVENT_WRITE._options = None
_SOCKETEVENT_CLOSED._options = None
_SOCKETEVENT._options = None
_SOCKETBUFFEREDTRACE._options = None
_SOCKETSTREAMEDTRACESEGMENT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/percent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/percent.proto',
  package='envoy.type',
  syntax='proto3',
  serialized_options=b'\n\030io.envoyproxy.envoy.typeB\014PercentProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x65nvoy/type/percent.proto\x12\nenvoy.type\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"1\n\x07Percent\x12&\n\x05value\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00Y@)\x00\x00\x00\x00\x00\x00\x00\x00\"\xb3\x01\n\x11\x46ractionalPercent\x12\x11\n\tnumerator\x18\x01 \x01(\r\x12L\n\x0b\x64\x65nominator\x18\x02 \x01(\x0e\x32-.envoy.type.FractionalPercent.DenominatorTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"=\n\x0f\x44\x65nominatorType\x12\x0b\n\x07HUNDRED\x10\x00\x12\x10\n\x0cTEN_THOUSAND\x10\x01\x12\x0b\n\x07MILLION\x10\x02\x42\x32\n\x18io.envoyproxy.envoy.typeB\x0cPercentProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_FRACTIONALPERCENT_DENOMINATORTYPE = _descriptor.EnumDescriptor(
  name='DenominatorType',
  full_name='envoy.type.FractionalPercent.DenominatorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HUNDRED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_THOUSAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILLION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=266,
  serialized_end=327,
)
_sym_db.RegisterEnumDescriptor(_FRACTIONALPERCENT_DENOMINATORTYPE)


_PERCENT = _descriptor.Descriptor(
  name='Percent',
  full_name='envoy.type.Percent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.type.Percent.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000Y@)\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=145,
)


_FRACTIONALPERCENT = _descriptor.Descriptor(
  name='FractionalPercent',
  full_name='envoy.type.FractionalPercent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='numerator', full_name='envoy.type.FractionalPercent.numerator', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denominator', full_name='envoy.type.FractionalPercent.denominator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FRACTIONALPERCENT_DENOMINATORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=327,
)

_FRACTIONALPERCENT.fields_by_name['denominator'].enum_type = _FRACTIONALPERCENT_DENOMINATORTYPE
_FRACTIONALPERCENT_DENOMINATORTYPE.containing_type = _FRACTIONALPERCENT
DESCRIPTOR.message_types_by_name['Percent'] = _PERCENT
DESCRIPTOR.message_types_by_name['FractionalPercent'] = _FRACTIONALPERCENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Percent = _reflection.GeneratedProtocolMessageType('Percent', (_message.Message,), {
  'DESCRIPTOR' : _PERCENT,
  '__module__' : 'envoy.type.percent_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.Percent)
  })
_sym_db.RegisterMessage(Percent)

FractionalPercent = _reflection.GeneratedProtocolMessageType('FractionalPercent', (_message.Message,), {
  'DESCRIPTOR' : _FRACTIONALPERCENT,
  '__module__' : 'envoy.type.percent_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.FractionalPercent)
  })
_sym_db.RegisterMessage(FractionalPercent)


DESCRIPTOR._options = None
_PERCENT.fields_by_name['value']._options = None
_FRACTIONALPERCENT.fields_by_name['denominator']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/agent/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencensus/proto/agent/common/v1/common.proto',
  package='opencensus.proto.agent.common.v1',
  syntax='proto3',
  serialized_options=b'\n#io.opencensus.proto.agent.common.v1B\013CommonProtoP\001ZIgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/common/v1\352\002 OpenCensus.Proto.Agent.Common.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-opencensus/proto/agent/common/v1/common.proto\x12 opencensus.proto.agent.common.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x02\n\x04Node\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.opencensus.proto.agent.common.v1.ProcessIdentifier\x12\x43\n\x0clibrary_info\x18\x02 \x01(\x0b\x32-.opencensus.proto.agent.common.v1.LibraryInfo\x12\x43\n\x0cservice_info\x18\x03 \x01(\x0b\x32-.opencensus.proto.agent.common.v1.ServiceInfo\x12J\n\nattributes\x18\x04 \x03(\x0b\x32\x36.opencensus.proto.agent.common.v1.Node.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x11ProcessIdentifier\x12\x11\n\thost_name\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa7\x02\n\x0bLibraryInfo\x12H\n\x08language\x18\x01 \x01(\x0e\x32\x36.opencensus.proto.agent.common.v1.LibraryInfo.Language\x12\x18\n\x10\x65xporter_version\x18\x02 \x01(\t\x12\x1c\n\x14\x63ore_library_version\x18\x03 \x01(\t\"\x95\x01\n\x08Language\x12\x18\n\x14LANGUAGE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x43PP\x10\x01\x12\x0b\n\x07\x43_SHARP\x10\x02\x12\n\n\x06\x45RLANG\x10\x03\x12\x0b\n\x07GO_LANG\x10\x04\x12\x08\n\x04JAVA\x10\x05\x12\x0b\n\x07NODE_JS\x10\x06\x12\x07\n\x03PHP\x10\x07\x12\n\n\x06PYTHON\x10\x08\x12\x08\n\x04RUBY\x10\t\x12\n\n\x06WEB_JS\x10\n\"\x1b\n\x0bServiceInfo\x12\x0c\n\x04name\x18\x01 \x01(\tB\xa2\x01\n#io.opencensus.proto.agent.common.v1B\x0b\x43ommonProtoP\x01ZIgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/common/v1\xea\x02 OpenCensus.Proto.Agent.Common.V1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_LIBRARYINFO_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='opencensus.proto.agent.common.v1.LibraryInfo.Language',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C_SHARP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERLANG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GO_LANG', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JAVA', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODE_JS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHP', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PYTHON', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUBY', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEB_JS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=716,
  serialized_end=865,
)
_sym_db.RegisterEnumDescriptor(_LIBRARYINFO_LANGUAGE)


_NODE_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='opencensus.proto.agent.common.v1.Node.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencensus.proto.agent.common.v1.Node.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencensus.proto.agent.common.v1.Node.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=461,
)

_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='opencensus.proto.agent.common.v1.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='opencensus.proto.agent.common.v1.Node.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_info', full_name='opencensus.proto.agent.common.v1.Node.library_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_info', full_name='opencensus.proto.agent.common.v1.Node.service_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='opencensus.proto.agent.common.v1.Node.attributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODE_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=461,
)


_PROCESSIDENTIFIER = _descriptor.Descriptor(
  name='ProcessIdentifier',
  full_name='opencensus.proto.agent.common.v1.ProcessIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_name', full_name='opencensus.proto.agent.common.v1.ProcessIdentifier.host_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='opencensus.proto.agent.common.v1.ProcessIdentifier.pid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='opencensus.proto.agent.common.v1.ProcessIdentifier.start_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=567,
)


_LIBRARYINFO = _descriptor.Descriptor(
  name='LibraryInfo',
  full_name='opencensus.proto.agent.common.v1.LibraryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='opencensus.proto.agent.common.v1.LibraryInfo.language', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exporter_version', full_name='opencensus.proto.agent.common.v1.LibraryInfo.exporter_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='core_library_version', full_name='opencensus.proto.agent.common.v1.LibraryInfo.core_library_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LIBRARYINFO_LANGUAGE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=865,
)


_SERVICEINFO = _descriptor.Descriptor(
  name='ServiceInfo',
  full_name='opencensus.proto.agent.common.v1.ServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencensus.proto.agent.common.v1.ServiceInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=894,
)

_NODE_ATTRIBUTESENTRY.containing_type = _NODE
_NODE.fields_by_name['identifier'].message_type = _PROCESSIDENTIFIER
_NODE.fields_by_name['library_info'].message_type = _LIBRARYINFO
_NODE.fields_by_name['service_info'].message_type = _SERVICEINFO
_NODE.fields_by_name['attributes'].message_type = _NODE_ATTRIBUTESENTRY
_PROCESSIDENTIFIER.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LIBRARYINFO.fields_by_name['language'].enum_type = _LIBRARYINFO_LANGUAGE
_LIBRARYINFO_LANGUAGE.containing_type = _LIBRARYINFO
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['ProcessIdentifier'] = _PROCESSIDENTIFIER
DESCRIPTOR.message_types_by_name['LibraryInfo'] = _LIBRARYINFO
DESCRIPTOR.message_types_by_name['ServiceInfo'] = _SERVICEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODE_ATTRIBUTESENTRY,
    '__module__' : 'opencensus.proto.agent.common.v1.common_pb2'
    # @@protoc_insertion_point(class_scope:opencensus.proto.agent.common.v1.Node.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _NODE,
  '__module__' : 'opencensus.proto.agent.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.common.v1.Node)
  })
_sym_db.RegisterMessage(Node)
_sym_db.RegisterMessage(Node.AttributesEntry)

ProcessIdentifier = _reflection.GeneratedProtocolMessageType('ProcessIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSIDENTIFIER,
  '__module__' : 'opencensus.proto.agent.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.common.v1.ProcessIdentifier)
  })
_sym_db.RegisterMessage(ProcessIdentifier)

LibraryInfo = _reflection.GeneratedProtocolMessageType('LibraryInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIBRARYINFO,
  '__module__' : 'opencensus.proto.agent.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.common.v1.LibraryInfo)
  })
_sym_db.RegisterMessage(LibraryInfo)

ServiceInfo = _reflection.GeneratedProtocolMessageType('ServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINFO,
  '__module__' : 'opencensus.proto.agent.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.common.v1.ServiceInfo)
  })
_sym_db.RegisterMessage(ServiceInfo)


DESCRIPTOR._options = None
_NODE_ATTRIBUTESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto',
  package='envoy.extensions.filters.network.dubbo_proxy.router.v3',
  syntax='proto3',
  serialized_options=b'\nDio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.router.v3B\013RouterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto\x12\x36\x65nvoy.extensions.filters.network.dubbo_proxy.router.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"A\n\x06Router:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.dubbo.router.v2alpha1.RouterB]\nDio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.router.v3B\x0bRouterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_ROUTER = _descriptor.Descriptor(
  name='Router',
  full_name='envoy.extensions.filters.network.dubbo_proxy.router.v3.Router',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.filter.dubbo.router.v2alpha1.Router',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=258,
)

DESCRIPTOR.message_types_by_name['Router'] = _ROUTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Router = _reflection.GeneratedProtocolMessageType('Router', (_message.Message,), {
  'DESCRIPTOR' : _ROUTER,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.router.v3.router_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.router.v3.Router)
  })
_sym_db.RegisterMessage(Router)


DESCRIPTOR._options = None
_ROUTER._options = None
# @@protoc_insertion_point(module_scope)
